import 'package:flutter/material.dart';
import 'package:midisynth/layout/game.dart';
import 'package:midisynth/layout/parameters.dart';
import 'package:midisynth/provider/data.dart';
import 'package:midisynth/utils/game_utils.dart';
import 'package:provider/provider.dart';
import 'package:overlay_support/overlay_support.dart';

class Home extends StatefulWidget {
  const Home({super.key});

  static const String id = 'home';

  @override
  HomeState createState() => HomeState();
}

class HomeState extends State<Home> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final Data myProvider = Provider.of<Data>(context);
    final double screenWidth = MediaQuery.of(context).size.width;

    final List<Widget> menuActions = [];

    if (myProvider.isGameRunning) {
      menuActions.add(
        TextButton(
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(4),
              border: Border.all(
                color: Colors.blue,
                width: 4,
              ),
            ),
            child: const Image(
              image: AssetImage('assets/icons/button_back.png'),
              fit: BoxFit.fill,
            ),
          ),
          onPressed: () => toast('Long press to quit game...'),
          onLongPress: () => GameUtils.quitGame(myProvider),
        ),
      );
    }

    return Scaffold(
      appBar: AppBar(
        actions: menuActions,
      ),
      body: SafeArea(
        child: myProvider.isGameRunning
            ? Game.buildGameWidget(myProvider, screenWidth)
            : Parameters.buildParametersSelector(myProvider),
      ),
    );
  }
}
